@@ -15,17 +15,17 @@
 import functools
 import json
 import logging
+from unittest import mock
 import uuid
 
 import fixtures
+import io
 from keystoneauth1 import session
 from keystoneauth1 import token_endpoint
-import mock
 from oslo_utils import encodeutils
 import requests
 from requests_mock.contrib import fixture
-import six
-from six.moves.urllib import parse
+from urllib import parse
 from testscenarios import load_tests_apply_scenarios as load_tests  # noqa
 import testtools
 from testtools import matchers
@@ -43,6 +43,7 @@ def original_only(f):
             self.skipTest('Skip logging tests for session client')
 
         return f(self, *args, **kwargs)
+    return wrapper
 
 
 class TestClient(testtools.TestCase):
@@ -66,7 +67,7 @@ class TestClient(testtools.TestCase):
 
         self.endpoint = 'http://example.com:9292'
         self.ssl_endpoint = 'https://example.com:9292'
-        self.token = u'abc123'
+        self.token = 'abc123'
 
         self.client = getattr(self, self.create_client)()
 
@@ -80,7 +81,7 @@ class TestClient(testtools.TestCase):
             'X-Service-Catalog': 'service_catalog',
         }
         # with token
-        kwargs = {'token': u'fake-token',
+        kwargs = {'token': 'fake-token',
                   'identity_headers': identity_headers}
         http_client_object = http.HTTPClient(self.endpoint, **kwargs)
         self.assertEqual('auth_token', http_client_object.auth_token)
@@ -96,10 +97,10 @@ class TestClient(testtools.TestCase):
             'X-Service-Catalog': 'service_catalog',
         }
         # without X-Auth-Token in identity headers
-        kwargs = {'token': u'fake-token',
+        kwargs = {'token': 'fake-token',
                   'identity_headers': identity_headers}
         http_client_object = http.HTTPClient(self.endpoint, **kwargs)
-        self.assertEqual(u'fake-token', http_client_object.auth_token)
+        self.assertEqual('fake-token', http_client_object.auth_token)
         self.assertTrue(http_client_object.identity_headers.
                         get('X-Auth-Token') is None)
 
@@ -210,12 +211,12 @@ class TestClient(testtools.TestCase):
         self.mock.get(self.endpoint + path, text=text,
                       headers={"Content-Type": "text/plain"})
 
-        headers = {"test": u'ni\xf1o'}
+        headers = {"test": 'ni\xf1o'}
         resp, body = self.client.get(path, headers=headers)
         self.assertEqual(text, resp.text)
 
     def test_headers_encoding(self):
-        value = u'ni\xf1o'
+        value = 'ni\xf1o'
         fake_location = b'http://web_server:80/images/fake.img'
         headers = {"test": value,
                    "none-val": None,
@@ -262,11 +263,25 @@ class TestClient(testtools.TestCase):
         ksarqh = mock_ksarq.call_args[1]['headers']
         # Only one Content-Type header (of any text-type)
         self.assertEqual(1, [encodeutils.safe_decode(key)
-                             for key in ksarqh.keys()].count(u'Content-Type'))
+                             for key in ksarqh.keys()].count('Content-Type'))
         # And it's the one we set
         self.assertEqual(b"application/openstack-images-v2.1-json-patch",
                          ksarqh[b"Content-Type"])
 
+    def test_request_id_header_session_client(self):
+        global_id = "req-%s" % uuid.uuid4()
+        kwargs = {'global_request_id': global_id}
+        auth = token_endpoint.Token(self.endpoint, self.token)
+        sess = session.Session(auth=auth)
+        http_client = http.SessionClient(sess, **kwargs)
+
+        path = '/v2/images/my-image'
+        self.mock.get(self.endpoint + path)
+        http_client.get(path)
+
+        headers = self.mock.last_request.headers
+        self.assertEqual(global_id, headers['X-OpenStack-Request-ID'])
+
     def test_raw_request(self):
         """Verify the path being used for HTTP requests reflects accurately."""
         headers = {"Content-Type": "text/plain"}
@@ -281,7 +296,7 @@ class TestClient(testtools.TestCase):
 
     def test_parse_endpoint(self):
         endpoint = 'http://example.com:9292'
-        test_client = http.HTTPClient(endpoint, token=u'adc123')
+        test_client = http.HTTPClient(endpoint, token='adc123')
         actual = test_client.parse_endpoint(endpoint)
         expected = parse.SplitResult(scheme='http',
                                      netloc='example.com:9292', path='',
@@ -290,24 +305,24 @@ class TestClient(testtools.TestCase):
 
     def test_get_connections_kwargs_http(self):
         endpoint = 'http://example.com:9292'
-        test_client = http.HTTPClient(endpoint, token=u'adc123')
+        test_client = http.HTTPClient(endpoint, token='adc123')
         self.assertEqual(600.0, test_client.timeout)
 
     def test__chunk_body_exact_size_chunk(self):
         test_client = http._BaseHTTPClient()
         bytestring = b'x' * http.CHUNKSIZE
-        data = six.BytesIO(bytestring)
+        data = io.BytesIO(bytestring)
         chunk = list(test_client._chunk_body(data))
         self.assertEqual(1, len(chunk))
         self.assertEqual([bytestring], chunk)
 
     def test_http_chunked_request(self):
         text = "Ok"
-        data = six.StringIO(text)
+        data = io.StringIO(text)
         path = '/v1/images/'
         self.mock.post(self.endpoint + path, text=text)
 
-        headers = {"test": u'chunked_request'}
+        headers = {"test": 'chunked_request'}
         resp, body = self.client.post(path, headers=headers, data=data)
         self.assertIsInstance(self.mock.last_request.body, types.GeneratorType)
         self.assertEqual(text, resp.text)
@@ -318,17 +333,17 @@ class TestClient(testtools.TestCase):
         text = 'OK'
         self.mock.post(self.endpoint + path, text=text)
 
-        headers = {"test": u'chunked_request'}
+        headers = {"test": 'chunked_request'}
         resp, body = self.client.post(path, headers=headers, data=data)
 
         self.assertEqual(text, resp.text)
-        self.assertIsInstance(self.mock.last_request.body, six.string_types)
+        self.assertIsInstance(self.mock.last_request.body, str)
         self.assertEqual(data, json.loads(self.mock.last_request.body))
 
     def test_http_chunked_response(self):
         data = "TEST"
         path = '/v1/images/'
-        self.mock.get(self.endpoint + path, body=six.StringIO(data),
+        self.mock.get(self.endpoint + path, body=io.StringIO(data),
                       headers={"Content-Type": "application/octet-stream"})
 
         resp, body = self.client.get(path)
@@ -341,7 +356,7 @@ class TestClient(testtools.TestCase):
             response = 'Ok'
             headers = {"Content-Type": "text/plain",
                        "test": "value1\xa5\xa6"}
-            fake = utils.FakeResponse(headers, six.StringIO(response))
+            fake = utils.FakeResponse(headers, io.StringIO(response))
             self.client.log_http_response(fake)
         except UnicodeDecodeError as e:
             self.fail("Unexpected UnicodeDecodeError exception '%s'" % e)
@@ -367,11 +382,11 @@ class TestClient(testtools.TestCase):
         self.assertTrue(mock_log.called, 'LOG.debug never called')
         self.assertTrue(mock_log.call_args[0],
                         'LOG.debug called with no arguments')
-        hd_regex = ".*\s-H\s+'\s*%s\s*:\s*%s\s*'.*" % (hd_name, hd_val)
+        hd_regex = r".*\s-H\s+'\s*%s\s*:\s*%s\s*'.*" % (hd_name, hd_val)
         self.assertThat(mock_log.call_args[0][0],
                         matchers.MatchesRegex(hd_regex),
                         'header not found in curl command')
-        body_regex = ".*\s-d\s+'%s'\s.*" % body
+        body_regex = r".*\s-d\s+'%s'\s.*" % body
         self.assertThat(mock_log.call_args[0][0],
                         matchers.MatchesRegex(body_regex),
                         'body not found in curl command')
@@ -390,12 +405,12 @@ class TestClient(testtools.TestCase):
         needles = {'key': key, 'cert': cert, 'cacert': cacert}
         for option, value in needles.items():
             if value:
-                regex = ".*\s--%s\s+('%s'|%s).*" % (option, value, value)
+                regex = r".*\s--%s\s+('%s'|%s).*" % (option, value, value)
                 self.assertThat(mock_log.call_args[0][0],
                                 matchers.MatchesRegex(regex),
                                 'no --%s option in curl command' % option)
             else:
-                regex = ".*\s--%s\s+.*" % option
+                regex = r".*\s--%s\s+.*" % option
                 self.assertThat(mock_log.call_args[0][0],
                                 matchers.Not(matchers.MatchesRegex(regex)),
                                 'unexpected --%s option in curl command' %
@@ -421,7 +436,7 @@ class TestClient(testtools.TestCase):
         self.assertTrue(mock_log.call_args[0],
                         'LOG.debug called with no arguments')
         self.assertThat(mock_log.call_args[0][0],
-                        matchers.MatchesRegex('.*\s-k\s.*'),
+                        matchers.MatchesRegex(r'.*\s-k\s.*'),
                         'no -k option in curl command')
 
     @mock.patch('glanceclient.common.http.LOG.debug')
@@ -444,7 +459,7 @@ class TestClient(testtools.TestCase):
         logger = self.useFixture(fixtures.FakeLogger(level=logging.DEBUG))
         data = "TEST"
         path = '/v1/images/'
-        self.mock.get(self.endpoint + path, body=six.StringIO(data),
+        self.mock.get(self.endpoint + path, body=io.StringIO(data),
                       headers={"Content-Type": "application/octet-stream",
                                'x-openstack-request-id': "1234"})
 
@@ -473,7 +488,7 @@ class TestClient(testtools.TestCase):
         headers = self.mock.last_request.headers
         self.assertEqual(refreshed_token, headers['X-Auth-Token'])
         # regression check for bug 1448080
-        unicode_token = u'ni\xf1o+=='
+        unicode_token = 'ni\xf1o+=='
         http_client.auth_token = unicode_token
         http_client.get(path)
         headers = self.mock.last_request.headers
